@@ -5,7 +5,7 @@ testAtmos <- function()
     {
     wave    = 400:700
     
-    junk = atmosTransmittance( c(500,1000,2000), wave=wave, aerosol=list(metrange=1000) )
+    junk = atmosTransmittance( c(500,1000,2000), wavelength=wave, aerosols=list(metrange=1000) )
         
     #   for special sequence wave[], reference wavelength 550nm is index 151
     err = junk[ 550 - wave[1] + 1,  2 ] - 0.02
